[Patch} Make some error dialogs higgy...
- From: Dave Bordoley <bordoley msu edu>
- To: nautilus-list gnome org
- Subject: [Patch} Make some error dialogs higgy...
- Date: 30 Jan 2003 14:52:58 -0500
This patch fixes some of the transfer error dialogs to be more hig
compliant. No string changes here, although i would like to add some
mneumonics to these when we are no longer in string freeze.
I realize this can't go in till after 2.2 is out the door.
Comments?
dave
Index: ChangeLog
===================================================================
RCS file: /cvs/gnome/nautilus/ChangeLog,v
retrieving revision 1.5683
diff -u -p -r1.5683 ChangeLog
--- ChangeLog 29 Jan 2003 10:20:47 -0000 1.5683
+++ ChangeLog 30 Jan 2003 19:34:04 -0000
@@ -1,3 +1,12 @@
+2003-01-30 David Bordoley <bordoley msu edu>
+
+ * lbnautilus-private/nautilus-file-operations.c
+ (handle_transfer_vfs_error):
+ Fixed dialogs to use GTK_STOCK_CANCEL/GTK_STOCK_OK
+ instead of stop where appropriate. Fix button order to be
+ HIG compliant.
+
+
2003-01-29 Alexander Larsson <alexl redhat com>
* libnautilus-private/nautilus-directory-async.c (file_info_start):
Index: libnautilus-private/nautilus-file-operations.c
===================================================================
RCS file: /cvs/gnome/nautilus/libnautilus-private/nautilus-file-operations.c,v
retrieving revision 1.162
diff -u -p -r1.162 nautilus-file-operations.c
--- libnautilus-private/nautilus-file-operations.c 17 Jan 2003 08:53:29 -0000 1.162
+++ libnautilus-private/nautilus-file-operations.c 30 Jan 2003 19:34:36 -0000
@@ -800,7 +800,7 @@ handle_transfer_vfs_error (const GnomeVF
switch (transfer_info->error_mode) {
case GNOME_VFS_XFER_ERROR_MODE_QUERY:
/* transfer error, prompt the user to continue or stop */
/* stop timeout while waiting for user */
nautilus_file_operations_progress_pause_timeout (transfer_info->progress_dialog);
@@ -911,7 +911,7 @@ handle_transfer_vfs_error (const GnomeVF
error_kind == ERROR_SOURCE_IN_TARGET) {
/* We can't continue, just tell the user. */
eel_run_simple_dialog (parent_for_error_dialog (transfer_info),
- TRUE, text, dialog_title, _("Stop"), NULL);
+ TRUE, text, dialog_title, GTK_STOCK_OK, NULL);
error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
} else if ((error_location == ERROR_LOCATION_SOURCE
@@ -926,16 +926,16 @@ handle_transfer_vfs_error (const GnomeVF
error_dialog_button_pressed = eel_run_simple_dialog
(parent_for_error_dialog (transfer_info), TRUE, text,
dialog_title,
- _("Skip"), _("Stop"), NULL);
+ GTK_STOCK_CANCEL, _("Skip"), NULL);
switch (error_dialog_button_pressed) {
case 0:
- error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_SKIP;
- break;
- case 1:
case GTK_RESPONSE_DELETE_EVENT:
error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
break;
+ case 1:
+ error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_SKIP;
+ break;
default:
g_assert_not_reached ();
error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
@@ -946,17 +946,17 @@ handle_transfer_vfs_error (const GnomeVF
error_dialog_button_pressed = eel_run_simple_dialog
(parent_for_error_dialog (transfer_info), TRUE, text,
dialog_title,
- _("Skip"), _("Retry"), _("Stop"), NULL);
+ _("Skip"), GTK_STOCK_CANCEL, _("Retry"), NULL);
switch (error_dialog_button_pressed) {
case 0:
error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_SKIP;
break;
case 1:
- error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_RETRY;
+ error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
break;
case 2:
- error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_ABORT;
+ error_dialog_result = GNOME_VFS_XFER_ERROR_ACTION_RETRY;
break;
default:
g_assert_not_reached ();
@@ -800,7 +800,7 @@ handle_transfer_vfs_error (const GnomeVF
switch (transfer_info->error_mode) {
case GNOME_VFS_XFER_ERROR_MODE_QUERY:
- /* transfer error, prompt the user to continue or stop */
+ /* transfer error, prompt the user to continue or cancel */
/* stop timeout while waiting for user */
nautilus_file_operations_progress_pause_timeout (transfer_info->progress_dialog);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]